@@ -228,7 +228,7 @@ def DrawGraph(self,  QtGui):
     #            for i in range(0, data.GraphBitMapLen,  decade): #full hours
                 for i in range(OffsetToLastFullHour-decade, max(data.GraphBitMapLen, records.Index)+decade,  decade): #full hours
 #                    h=(h0+int(i/decade)+1) % 24
-                    h=h+1
+                    h=(h+1) % 24
     #                print i
                     paint.drawLine(i, data.Ysize, i, data.Ysize+10) 
                     paint.setFont(QtGui.QFont('Decorative', 18))
@@ -251,7 +251,7 @@ def DrawGraph(self,  QtGui):
     #            for i in range(OffsetToLastFullHour-decade, 781+decade,  decade): #full hours
                 for i in range(OffsetToLastFullHour-decade, max(data.GraphBitMapLen, records.Index)+decade,  decade): #full hours
 #                    h=(h0+int(i/decade)+1) % 24
-                    h=h+1
+                    h=(h+1) % 24
     #                print i
                     paint.drawLine(i, data.Ysize, i, data.Ysize+10) 
                     paint.drawText(i-15, data.Ysize+30, str(h)+":00")
@@ -353,25 +353,27 @@ def DrawGraph(self,  QtGui):
     #            if(x11>1 and x11<779):        
             paint.drawRect(x10,  4,  1,  10)  #Last Alarm opportunity
                     
-            if(data.AlarmIsActive==True or data.run==False): #only show alarm if alarm occured or in record
+                    
+                    
+            if(data.AlarmIsActive==True or data.run==False): #only show alarm if alarm occured or in view mode
     #            if(records.Index>=Tuple2Index(records.AlarmTimeWindowEnd_tuple)): #only show alarm dot when alarm really came
                 if(records.AlarmTime_seconds!=-1):
-    #                print "AlarmTimeWindowEnd:",  records.AlarmTimeWindowEnd_seconds,  "AlarmTime:",  records.AlarmTime_seconds
+                    print "AlarmTimeWindowEnd:",  records.AlarmTimeWindowEnd_seconds,  "AlarmTime:",  records.AlarmTime_seconds,  "records.EndTime_seconds:",records.EndTime_seconds  
     #                EndTime_seconds=Tuple2Seconds(records.StartTime_tuple)+records.Index*records.Sampling_interval*records.Value_smoothing/1000
-                    if(records.EndTime_seconds>=records.AlarmTime_seconds): #alarm got set off during recording
+                    if(records.EndTime_seconds>=records.AlarmTime_seconds-60): #alarm got set off during recording (-60 is workaround)
                         paint.setBrush(QtGui.QColor(data.AlarmColor))
                         paint.setPen(QtGui.QColor(data.AlarmColor))  
                         if(records.AlarmTimeWindowEnd_seconds<=records.AlarmTime_seconds):
-        #                    print "Alarm due end of alarm time window"
+#                            print "Alarm due end of alarm time window"
                             a0=Tuple2Index(records.AlarmTime_tuple)-data.Derivation*Xscale
                         else:
-        #                    print "alarm due movement"
+#                            print "alarm due movement"
                             a0=Tuple2Index(records.AlarmTime_tuple)-data.Derivation
                         a00=(a0-GraphStart_index)/Xscale
                         paint.drawEllipse(a00-5, 15, 10, 10)     
             #            print "AlarmTimeWindow:",  x1,  x10,  "Alarm:",  a0,  a00
-        #            else:
-        #                print "Alarm set, but never occured"
+#                    else:
+#                        print "Alarm set, but never occured"
 
 
 
