@@ -207,8 +207,9 @@ def MeasurementTimerLoop(): #(interval: sampling*sample_smoothing*value_smoothin
             data.Status="Stopped, array is full!"
             QtGui.QMessageBox.warning(RecordWindow, 'Memory is full!', "You reached the end of the recording capacity!\nThe recording stops now.", QtGui.QMessageBox.Ok)
 #            RecordWindow.StopMeasurement()
-            StopMeasurement() #but keep alarm active!
+            StopMeasurement() #stop but keep alarm active!
     
+    ProcessAlarm()        
     
     if(data.DisplayIsOn==True):
         if(data.debug==1): print "-> o Update screen"
@@ -223,7 +224,7 @@ def MeasurementTimerLoop(): #(interval: sampling*sample_smoothing*value_smoothin
         if(data.StopAfterAlarm==True):
 #            print "Stop measurement, alarm is active"
             data.Status="Alarm got activated, stopped recording"
-            StopMeasurement() #but keep alarm active!
+            StopMeasurement() #stop but keep alarm active!
   
 
 
@@ -335,6 +336,9 @@ def InitMeasurement():
 def StopMeasurement():
     global app
     
+    GenerateStatisticData()   
+    GenerateGraphBitmap(RecordWindow)    
+    
     RecordWindow.UpdateScreenStop()
     RecordWindow.Canvas.update()
     RecordWindow.UpdateScreen()
@@ -444,7 +448,7 @@ class frmStartWindow(QMainWindow):
 
         
         if(data.app_path!="./"): #only needed if not started in app path
-            self.ui.lblIcon.setPixmap(QtGui.QPixmap(data.app_path+"img/"+"SleepAnalyser.png"))
+            self.ui.lblIcon.setPixmap(QtGui.QPixmap(data.app_path+"img/"+"SleepAnalyser2.png"))
             self.ui.bSetAlarm.setIcon(QIcon(data.app_path+"img/"+"SleepAnalyser.png"))
 #            self.ui.bQuick.setIcon(QIcon(data.app_path+"img/"+"krec.png"))
             self.ui.bCollecting.setIcon(QIcon(data.app_path+"img/"+"krec.png"))
@@ -1514,7 +1518,7 @@ class frmAdditionalInfoWindow(QMainWindow):
                 a1=strftime("%a. %d.%m.%Y  %H:%M:%S", records.AlarmTimeWindowEnd_tuple) 
             alarm="<b>Alarm Time Window:</b> "+a0+" - "+a1 + "<br>"
             if(records.AlarmTime_seconds!=-1): #alarm was set
-                if(records.EndTime_seconds>=records.AlarmTime_seconds): #alarm got set off during recording
+                if(records.EndTime_seconds>=records.AlarmTime_seconds-60): #alarm got set off during recording (-60 is workaround)
                     alarm=alarm+"<b>Alarm:</b> Alarm went off on: "+strftime("%a. %d.%m.%Y  %H:%M:%S", records.AlarmTime_tuple)+"<br>"
                     if(records.AlarmTimeWindowEnd_seconds<=records.AlarmTime_seconds):
                         alarm=alarm+"<b>Alarm reason:</b> End of alarm time window<br>"
